core/spatial_hashing library

Classes

SpatialHashing<T>
Data structure for spatial hashing to get widgets to be built quickly based on their position in a 2D grid.

Typedefs

PointData<T> = ({T data, Point<num> point})